# pydraughts
pydraughts is a draughts library for Python.
It is based on [ImparaAI/checkers](https://github.com/ImparaAI/checkers).

## License
pydraughts is licensed under the GPL 3 (or any later version at your option). Check out LICENSE.txt for the full text.
The license of [ImparaAI/checkers](https://github.com/ImparaAI/checkers) is also present [here](ImparaAI checkers LICENSE).
